"use strict";
/// <reference.d='/node_modules/@types/node/index.d.ts' />
/// <reference.d='/node_modules/@types/es6-promise/index.d.ts' />
Object.defineProperty(exports, "__esModule", { value: true });
const ResponseParser_1 = require("./ResponseParser");
const net_1 = require("net");
class Client {
    // @todo: Add tracking of idle status.
    /**
     * Creates new client.
     *
     * @param {string} host - Hostname of MPD server.
     * @param {number} port - Port of MPD server.
     */
    constructor(host, port) {
        this.host = host;
        this.port = port;
    }
    /**
     * Create socket; connect and handle base response from server.
     *
     * @returns {Promise<(Socket|string)>} - Promise obj with connected socket, error otherwise.
     */
    connect() {
        return new Promise((resolve, reject) => {
            // As NodeJS works in async mode we can't store socket as
            // class property.
            const socket = new net_1.Socket();
            socket.connect(this.port, this.host);
            // Force returning result in human-readable view to evade toString conversion.
            socket.setEncoding('utf8');
            // Handle socket events.
            socket.on('data', (data) => {
                // Because there are can be multiple command invocation for the same client instance.
                // So it should be local variable passed as result to resolve callback.
                resolve(socket);
            });
            socket.on('error', error => {
                reject(error);
            });
        });
    }
    /**
     * Execute Executable object.
     *
     * @param {Executable} command - Command or CommandList exemplar.
     *
     * @returns {Promise<string>} - Promise which will return parsed response or it will reject with an error.
     */
    execute(command) {
        return new Promise((resolve, reject) => {
            // Connect to sever and if success execute an command and close socket.
            this.connect().then((socket) => {
                let result = '';
                socket.on('data', (data) => {
                    result += data;
                });
                socket.on('error', (error) => {
                    reject(error);
                });
                socket.on('end', () => {
                    // When we collected all data returned from MPD we can pass it to Parser.
                    let responseParser = new ResponseParser_1.ResponseParser(result, command);
                    responseParser.parse(resolve, reject);
                });
                // Need to send FIN packet as we don't want to write something else.
                socket.end(command.buildQuery());
            }, (error) => {
                reject(error);
            });
        });
    }
}
exports.MPDClient = Client;
