"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Command {
    /**
     * Creates new command.
     *
     * @param {string} command - Command for execution.
     * @param {*[]} args - Optional arguments for
     *
     * @constructor
     */
    constructor(command, args = []) {
        this.command = command;
        this.args = args;
        this.command = command.trim();
    }
    /**
     * Query should have this form:
     *  command\t"arg1"\t"arg2"\t"arg3"\t"argN"\n
     *
     * @return {string} - Built query.
     */
    buildQuery() {
        if (!this.query) {
            this.query =
                this.args
                    .reduce((prev, item) => {
                    prev.push('"' + item.toString().replace('"', "'") + '"');
                    return prev;
                }, [this.command])
                    .join('\t') + '\n';
        }
        return this.query;
    }
    /**
     * Getter for args prop.
     *
     * @returns {*} - Array of args.
     */
    getArgs() {
        return this.args;
    }
    /**
     * Getter for command prop.
     *
     * @returns {*} - Command string.
     */
    getCommand() {
        return this.command;
    }
}
exports.MPDCommand = Command;
